@@ -1,7 +1,5 @@
 mod completions;
 mod config;
-mod debug;
-mod error;
 mod lang;
 mod lsp;
 mod new;
@@ -15,11 +13,11 @@ use anyhow::Result;
 use clap::{Parser, Subcommand};
 
 use completions::{run_shell_completion, CompletionsArg};
-use error::exit_with_error;
 use lsp::{run_language_server, LspArg};
 use new::{run_create_new, NewArg};
 use run::{register_custom_language_if_is_run, run_with_pattern, RunArg};
 use scan::{run_with_config, ScanArg};
+use utils::exit_with_error;
 use verify::{run_test_rule, TestArg};
 
 const LOGO: &str = r#"
@@ -183,6 +181,9 @@ mod test_cli {
     ok("run -p test --selector identifier"); // pattern + selector
     ok("run -p test --selector identifier -l js");
     ok("run -p test --follow");
+    ok("run -p test --globs '*.js'");
+    ok("run -p test --globs '*.{js, ts}'");
+    ok("run -p test --globs '*.js' --globs '*.ts'");
     error("run test");
     error("run --debug-query test"); // missing lang
     error("run -r Test dir");
@@ -209,6 +210,9 @@ mod test_cli {
     ok("scan --interactive");
     ok("scan --follow");
     ok("scan -r test.yml -c test.yml --json dir"); // allow registering custom lang
+    ok("scan --globs '*.js'");
+    ok("scan --globs '*.{js, ts}'");
+    ok("scan --globs '*.js' --globs '*.ts'");
     error("scan -i --json dir"); // conflict
     error("scan --report-style rich --json dir"); // conflict
     error("scan -r test.yml --inline-rules '{}'"); // conflict
