@@ -8,11 +8,11 @@ use clap::{builder::PossibleValue, Parser, ValueEnum};
 use ignore::WalkParallel;
 
 use crate::config::register_custom_language;
-use crate::debug::DebugFormat;
-use crate::error::ErrorContext as EC;
 use crate::lang::SgLang;
 use crate::print::{ColoredPrinter, Diff, Heading, InteractivePrinter, JSONPrinter, Printer};
+use crate::utils::ErrorContext as EC;
 use crate::utils::{filter_file_pattern, InputArgs, MatchUnit, OutputArgs};
+use crate::utils::{DebugFormat, FileStats, RunStats};
 use crate::utils::{Items, PathWorker, StdInWorker, Worker};
 
 // NOTE: have to register custom lang before clap read arg
@@ -198,13 +198,20 @@ fn run_pattern_with_printer(arg: RunArg, printer: impl Printer + 'static) -> Res
   } else if arg.lang.is_some() {
     RunWithSpecificLang::new(arg, printer)?.run_path()
   } else {
-    RunWithInferredLang { arg, printer }.run_path()
+    let stats = arg.output.tracing.run_stats();
+    RunWithInferredLang {
+      arg,
+      printer,
+      stats,
+    }
+    .run_path()
   }
 }
 
 struct RunWithInferredLang<Printer> {
   arg: RunArg,
   printer: Printer,
+  stats: RunStats,
 }
 impl<P: Printer> Worker for RunWithInferredLang<P> {
   type Item = (MatchUnit<Pattern<SgLang>>, SgLang);
@@ -227,15 +234,24 @@ impl<P: Printer> Worker for RunWithInferredLang<P> {
         }
       }
     }
+    // TODO: print stats
+    // let file_stats = &self.stats.file_stats;
+    // eprintln!("Scanned: {}, Skipped: {}", file_stats.scanned(), file_stats.skipped());
     printer.after_print()?;
+    if let Some(stats) = self.stats.print(self.arg.output.json.is_some()) {
+      eprintln!("{}", stats);
+    }
     Ok(())
   }
 }
 
 impl<P: Printer> PathWorker for RunWithInferredLang<P> {
-  fn build_walk(&self) -> WalkParallel {
+  fn build_walk(&self) -> Result<WalkParallel> {
     self.arg.input.walk()
   }
+  fn get_stats(&self) -> &FileStats {
+    &self.stats.file_stats
+  }
 
   fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
     let lang = SgLang::from_path(path)?;
@@ -258,6 +274,7 @@ struct RunWithSpecificLang<Printer> {
   printer: Printer,
   pattern: Pattern<SgLang>,
   rewrite: Option<Fixer<SgLang>>,
+  stats: RunStats,
 }
 
 impl<Printer> RunWithSpecificLang<Printer> {
@@ -272,11 +289,13 @@ impl<Printer> RunWithSpecificLang<Printer> {
     } else {
       None
     };
+    let stats = arg.output.tracing.run_stats();
     Ok(Self {
       arg,
       printer,
       pattern,
       rewrite,
+      stats,
     })
   }
 }
@@ -293,6 +312,9 @@ impl<P: Printer> Worker for RunWithSpecificLang<P> {
       has_matches = true;
     }
     printer.after_print()?;
+    if let Some(stats) = self.stats.print(self.arg.output.json.is_some()) {
+      eprintln!("{}", stats);
+    }
     if !has_matches && self.pattern.has_error() {
       Err(anyhow::anyhow!(EC::PatternHasError))
     } else {
@@ -302,9 +324,12 @@ impl<P: Printer> Worker for RunWithSpecificLang<P> {
 }
 
 impl<P: Printer> PathWorker for RunWithSpecificLang<P> {
-  fn build_walk(&self) -> WalkParallel {
+  fn build_walk(&self) -> Result<WalkParallel> {
     let lang = self.arg.lang.expect("must present");
-    self.arg.input.walk_lang(lang)
+    Ok(self.arg.input.walk_lang(lang))
+  }
+  fn get_stats(&self) -> &FileStats {
+    &self.stats.file_stats
   }
   fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
     let arg = &self.arg;
@@ -373,12 +398,14 @@ mod test {
         stdin: false,
         follow: false,
         paths: vec![PathBuf::from(".")],
+        globs: vec![],
       },
       output: OutputArgs {
         color: ColorArg::Never,
         interactive: false,
         json: None,
         update_all: false,
+        tracing: Default::default(),
       },
       before: 0,
       after: 0,
