@@ -10,13 +10,14 @@ use ignore::WalkParallel;
 use regex::Regex;
 
 use crate::config::{find_rules, read_rule_file, register_custom_language};
-use crate::error::ErrorContext as EC;
 use crate::lang::SgLang;
 use crate::print::{
   CloudPrinter, ColoredPrinter, Diff, InteractivePrinter, JSONPrinter, Platform, Printer,
   ReportStyle, SimpleFile,
 };
+use crate::utils::ErrorContext as EC;
 use crate::utils::{filter_file_interactive, InputArgs, OutputArgs};
+use crate::utils::{FileStats, RuleStats, ScanStats};
 use crate::utils::{Items, PathWorker, StdInWorker, Worker};
 
 type AstGrep = ast_grep_core::AstGrep<StrDoc<SgLang>>;
@@ -101,9 +102,11 @@ struct ScanWithConfig<Printer> {
   arg: ScanArg,
   printer: Printer,
   configs: RuleCollection<SgLang>,
+  stats: ScanStats,
 }
 impl<P: Printer> ScanWithConfig<P> {
   fn try_new(mut arg: ScanArg, printer: P) -> Result<Self> {
+    let mut rule_stats = RuleStats::default();
     let configs = if let Some(path) = &arg.rule {
       let rules = read_rule_file(path, None)?;
       RuleCollection::try_new(rules).context(EC::GlobPattern)?
@@ -112,12 +115,16 @@ impl<P: Printer> ScanWithConfig<P> {
         .with_context(|| EC::ParseRule("INLINE_RULES".into()))?;
       RuleCollection::try_new(rules).context(EC::GlobPattern)?
     } else {
-      find_rules(arg.config.take(), arg.filter.as_ref())?
+      let (configs, r_stats) = find_rules(arg.config.take(), arg.filter.as_ref())?;
+      rule_stats = r_stats;
+      configs
     };
+    let stats = arg.output.tracing.scan_stats(rule_stats);
     Ok(Self {
       arg,
       printer,
       configs,
+      stats,
     })
   }
 }
@@ -154,6 +161,9 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
       }
     }
     self.printer.after_print()?;
+    if let Some(stats) = self.stats.print(self.arg.output.json.is_some()) {
+      eprintln!("{}", stats);
+    }
     if error_count > 0 {
       Err(anyhow::anyhow!(EC::DiagnosticError(error_count)))
     } else {
@@ -163,7 +173,10 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
 }
 
 impl<P: Printer> PathWorker for ScanWithConfig<P> {
-  fn build_walk(&self) -> WalkParallel {
+  fn get_stats(&self) -> &FileStats {
+    &self.stats.file_stats
+  }
+  fn build_walk(&self) -> Result<WalkParallel> {
     self.arg.input.walk()
   }
   fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
@@ -310,12 +323,14 @@ rule:
         paths: vec![PathBuf::from(".")],
         stdin: false,
         follow: false,
+        globs: vec![],
       },
       output: OutputArgs {
         interactive: false,
         json: None,
         update_all: false,
         color: ColorArg::Never,
+        tracing: Default::default(),
       },
       format: None,
     }
