@@ -39,7 +39,10 @@ impl MatchStrictness {
   ) -> MatchOneNode {
     use MatchStrictness as M;
     let k = candidate.kind_id();
-    if k == kind && text == candidate.text() {
+    // work around ast-grep/ast-grep#1419 and tree-sitter/tree-sitter-typescript#306
+    // tree-sitter-typescript has wrong span of unnamed node so text would not match
+    // just compare kind for unnamed node
+    if k == kind && (!is_named || text == candidate.text()) {
       return MatchOneNode::MatchedBoth;
     }
     let (skip_goal, skip_candidate) = match self {
